summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasline_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasline_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvasline_imp.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kjsembed/qtbindings/qcanvasline_imp.cpp b/kjsembed/qtbindings/qcanvasline_imp.cpp
index af6a7b53..907573f0 100644
--- a/kjsembed/qtbindings/qcanvasline_imp.cpp
+++ b/kjsembed/qtbindings/qcanvasline_imp.cpp
@@ -23,12 +23,12 @@
*/
namespace KJSEmbed {
-TTQCanvasLineImp::TQCanvasLineImp( KJS::ExecState *exec, int mid, bool constructor )
+TQCanvasLineImp::TQCanvasLineImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-TTQCanvasLineImp::~TQCanvasLineImp()
+TQCanvasLineImp::~TQCanvasLineImp()
{
}
@@ -43,7 +43,7 @@ void TQCanvasLineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obje
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -74,7 +74,7 @@ void TQCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -87,25 +87,25 @@ void TQCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TTQCanvasLine pointer from an Object.
*/
-TTQCanvasLine *TQCanvasLineImp::toTQCanvasLine( KJS::Object &self )
+TQCanvasLine *TQCanvasLineImp::toTQCanvasLine( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TTQObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TTQCanvasLine *>( obj );
+ return dynamic_cast<TQCanvasLine *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TTQCanvasLine" )
+ if ( op->typeName() != "TQCanvasLine" )
return 0;
- return op->toNative<TTQCanvasLine>();
+ return op->toNative<TQCanvasLine>();
}
/**
@@ -123,7 +123,7 @@ KJS::Object TQCanvasLineImp::construct( KJS::ExecState *exec, const KJS::List &a
break;
}
- TTQString msg = i18n("TQCanvasLineCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("TQCanvasLineCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -131,15 +131,15 @@ KJS::Object TQCanvasLineImp::construct( KJS::ExecState *exec, const KJS::List &a
KJS::Object TQCanvasLineImp::TQCanvasLine_1( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter TTQCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
- TTQCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
- // We should now create an instance of the TTQCanvasLine object
+ // We should now create an instance of the TQCanvasLine object
- TTQCanvasLine *ret = new TTQCanvasLine(
+ TQCanvasLine *ret = new TQCanvasLine(
arg0 );
@@ -180,7 +180,7 @@ KJS::Value TQCanvasLineImp::call( KJS::ExecState *exec, KJS::Object &self, const
break;
}
- TTQString msg = i18n( "TQCanvasLineImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "TQCanvasLineImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -207,7 +207,7 @@ KJS::Value TQCanvasLineImp::setPoints_3( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasLineImp::startPoint_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPoint ret;
+ TQPoint ret;
ret = instance->startPoint( );
return convertToValue( exec, ret );
@@ -216,7 +216,7 @@ KJS::Value TQCanvasLineImp::startPoint_4( KJS::ExecState *exec, KJS::Object &obj
KJS::Value TQCanvasLineImp::endPoint_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPoint ret;
+ TQPoint ret;
ret = instance->endPoint( );
return convertToValue( exec, ret );
@@ -238,7 +238,7 @@ KJS::Value TQCanvasLineImp::setPen_7( KJS::ExecState *exec, KJS::Object &obj, co
// Unsupported parameter TQPen
return KJS::Value();
- TTQPen arg0; // Dummy
+ TQPen arg0; // Dummy
instance->setPen(
arg0 );
@@ -87,25 +87,25 @@ void TQCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TTQCanvasLine pointer from an Object.
+ * Extract a TQCanvasLine pointer from an Object.
*/